@@ -1,16 +1,17 @@
-# @(#)Ident: AddingFiles.pm 2013-05-04 17:19 pjf ;
+# @(#)Ident: AddingFiles.pm 2013-06-30 18:47 pjf ;
 
 package Module::Provision::TraitFor::AddingFiles;
 
-use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.16.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use namespace::sweep;
+use version; our $VERSION = qv( sprintf '0.17.%d', q$Rev: 11 $ =~ /\d+/gmx );
 
-use Moose::Role;
 use Class::Usul::Constants;
-use Class::Usul::Functions qw(classfile throw);
+use Class::Usul::Functions  qw( classfile throw );
+use Moo::Role;
 
-requires qw(add_to_vcs appldir binsdir exec_perms libdir module_abstract
-            render_template stash testdir);
+requires qw( add_to_vcs appldir binsdir exec_perms libdir loc method
+             module_abstract next_argv output project
+             render_template stash testdir );
 
 # Construction
 around 'generate_metadata' => sub {
@@ -26,7 +27,7 @@ around 'generate_metadata' => sub {
 sub module : method {
    my $self = shift; my $target = $self->_get_target( 'libdir', \&classfile );
 
-   $self->output( $self->loc( 'Adding new module' ) );
+   $self->output( 'Adding new module' );
    $target = $self->render_template( 'perl_module.pm', $target );
    $self->add_to_vcs( $target, 'module' );
    return OK;
@@ -35,7 +36,7 @@ sub module : method {
 sub program : method {
    my $self = shift; my $target = $self->_get_target( 'binsdir' );
 
-   $self->output( $self->loc( 'Adding new program' ) );
+   $self->output( 'Adding new program' );
    $target = $self->render_template( 'perl_program.pl', $target );
    chmod $self->exec_perms, $target->pathname;
    $self->add_to_vcs( $target, 'program' );
@@ -45,7 +46,7 @@ sub program : method {
 sub test : method {
    my $self = shift; my $target = $self->_get_target( 'testdir' );
 
-   $self->output( $self->loc( 'Adding new test' ) );
+   $self->output( 'Adding new test' );
    $target = $self->render_template( '10test_script.t', $target );
    $self->add_to_vcs( $target, 'test' );
    return OK;
@@ -53,10 +54,10 @@ sub test : method {
 
 # Private methods
 sub _get_target {
-   my ($self, $dir, $f) = @_; my $argv = $self->extra_argv;
+   my ($self, $dir, $f) = @_;
 
-   my $car      = shift @{ $argv } or throw 'No target specified';
-   my $abstract = shift @{ $argv }
+   my $car      = $self->next_argv or throw $self->loc( 'No target specified' );
+   my $abstract = $self->next_argv
                || ($self->method eq 'program' ? $self->_program_abstract
                                               : $self->module_abstract );
 
@@ -99,7 +100,7 @@ Module::Provision::TraitFor::AddingFiles - Adds additional files to the project
 
 =head1 Version
 
-This documents version v0.16.$Rev: 1 $ of L<Module::Provision::TraitFor::AddingFiles>
+This documents version v0.17.$Rev: 11 $ of L<Module::Provision::TraitFor::AddingFiles>
 
 =head1 Description
 
@@ -118,19 +119,19 @@ Defines no attributes
 
 =head1 Subroutines/Methods
 
-=head2 module
+=head2 module - Create a new Perl module file
 
    $exit_code = $self->module;
 
 Creates a new module specified by the class name on the command line
 
-=head2 program
+=head2 program - Create a new Perl program file
 
    $exit_code = $self->program;
 
 Creates a new program specified by the program name on the command line
 
-=head2 test
+=head2 test - Create a new Perl test script
 
    $exit_code = $self->test;
 
